| PostcodeMap | R Documentation |
rownames(matrix) to geographical coordinates.
matrix can be a Matrix or a sparseMatrix object storing baseline or observation data.
Requires the all postcode data tabulated in a data.frame called postcode.data available in the workspace.Map postcodes to coordinates
Returns and save 'postcode2coord.RData' a data frame that maps the postcodes included in rownames(matrix) to geographical coordinates.
matrix can be a Matrix or a sparseMatrix object storing baseline or observation data.
Requires the all postcode data tabulated in a data.frame called postcode.data available in the workspace.
PostcodeMap(matrix, postcode.field = "postcode")
matrix |
A |
A data.frame.
postcode2coord = PostcodeMap(observation.matrix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.