TimeFactor: Find temporal component of the baseline

View source: R/Init.r

TimeFactorR Documentation

Find temporal component of the baseline

Description

Returns a vector representing the temporal component of the baseline. This is obtained by calling cmle and predict.cmle, which fit a seasonal trend model to aggregated data and return its best estimate, respectively.

Usage

TimeFactor(
  case.df,
  save.on.dir = TRUE,
  get.from.dir = FALSE,
  date.time.field = "week",
  start = NULL,
  n.iterations = 20
)

Arguments

case.df

A data.frame containing the events.

save.on.dir

logical. If TRUE then the vector is saved in 'timefactor.RData' file.

get.from.dir

logical. If TRUE then the vector is obtained from the 'timefactor.RData' file.

date.time.field

A character string.

start

numeric. Starting parameters (not yet implemented).

n.iterations

An integer.

Value

A numeric vector.

Examples

time.factor = TimeFactor(case.df)

mcavallaro/rancovr documentation built on April 17, 2025, 7:21 p.m.