cmle2: Optimize function 'neg.log.like' conditioned on having the...

View source: R/time_utils.r

cmle2R Documentation

Optimize function neg.log.like conditioned on having the first three parameters fixed.

Description

Optimize function neg.log.like conditioned on having the first three parameters fixed.

Usage

cmle2(data, cpar)

Arguments

data

A numeric vector of event times.

cpar

numeric.

Value

numeric.

Examples

cmle2(data, c(1,1,1))

mcavallaro/rancovr documentation built on April 17, 2025, 7:21 p.m.