| TimeFactor | R Documentation |
Returns a vector representing the temporal component of the baseline. This is obtained by calling
cmle and predict.cmle, which fit a seasonal trend model to aggregated data and return its best estimate, respectively.
TimeFactor(
case.df,
save.on.dir = TRUE,
get.from.dir = FALSE,
date.time.field = "week",
start = NULL,
n.iterations = 20
)
case.df |
A |
save.on.dir |
|
get.from.dir |
|
date.time.field |
A |
start |
|
n.iterations |
An |
A numeric vector.
time.factor = TimeFactor(case.df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.