| cmle2 | R Documentation |
neg.log.like conditioned on having the first three parameters fixed.Optimize function neg.log.like conditioned on having the first three parameters fixed.
cmle2(data, cpar)
data |
A |
cpar |
|
numeric.
cmle2(data, c(1,1,1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.